elephant.test.test_conversion module — Elephant 0.5.0 documentation

# elephant.test.test_conversion module

Unit tests for the conversion module.

class `elephant.test.test_conversion.` `TimeHistogramTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `tearDown`()
  `test_binned_spiketrain_bin_edges`()
  `test_binned_spiketrain_different_units`()
  `test_binned_spiketrain_indices`()
  `test_binned_spiketrain_insufficient_arguments`()
  `test_binned_spiketrain_list`()
  `test_binned_spiketrain_list_numbins`()
  `test_binned_spiketrain_list_t_stop`()
  `test_binned_spiketrain_matrix`()
  `test_binned_spiketrain_matrix_storing`()
  `test_binned_spiketrain_neg_times`()
  `test_binned_spiketrain_neg_times_list`()
  `test_binned_spiketrain_numbins_type_error`()
  `test_binned_spiketrain_parameter_calc_tstart`()
  `test_binned_spiketrain_remove_matrix`()
  `test_binned_spiketrain_shape`()
  `test_binned_spiketrain_shape_list`()
  `test_binned_spiketrain_sparse`()
  `test_calc_attributes_error`()
  `test_consistency_errors`()
  `test_different_input_types`()
  `test_get_start_stop`()

class `elephant.test.test_conversion.` `binarize_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_binariz_rate_with_plain_array_and_units_typeerror`()
  `test_binariz_without_sampling_rate_valueerror`()
  `test_binarize_no_time`()
  `test_binarize_with_plain_array_exact`()
  `test_binarize_with_plain_array_exact_set_ends`()
  `test_binarize_with_quantities_exact`()
  `test_binarize_with_quantities_exact_set_ends`()
  `test_binarize_with_quantities_round_set_ends`()
  `test_binarize_with_spiketrain_exact`()
  `test_binarize_with_spiketrain_exact_set_ends`()
  `test_binarize_with_spiketrain_round`()

`elephant.test.test_conversion.` `get_nearest`(times, time)